@@ -3,6 +3,8 @@ import os
 
 import requests
 
+from .util import asteroid_to_names, crew_to_names
+
 logger = logging.getLogger(__name__)
 
 API_BASE_URL = "https://api.influenceth.io"
@@ -74,24 +76,32 @@ class InfluenceClient:
         result_json = result.json()
         return result_json
 
-    def get_asteroid(self, serial: int) -> dict:
+    def get_asteroid(self, serial: int, names: bool = False) -> dict:
         """Retrieves an asteroid, identified by a serial number, from the Influence API
 
         Args:
             serial (int): the serial number of the asteroid
+            names (bool): use string names for values if true, otherwise indices
 
         Returns:
             dict: the JSON response from the API
         """
-        return self._get_by_url(f"/v1/asteroids/{serial}")
+        item = self._get_by_url(f"/v1/asteroids/{serial}")
+        if names:
+            item = asteroid_to_names(item)
+        return item
 
-    def get_crewmate(self, serial: int) -> dict:
+    def get_crewmate(self, serial: int, names: bool = False) -> dict:
         """Retrieves a crewmate, identified by a serial number, from the Influence API
 
         Args:
             serial (int): the serial number of the asteroid
+            names (bool): use string names for values  if true, otherwise indices
 
         Returns:
             dict: the JSON response from the API
         """
-        return self._get_by_url(f"/v1/crew/{serial}")
+        item = self._get_by_url(f"/v1/crew/{serial}")
+        if names:
+            item = crew_to_names(item)
+        return item
